# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class FirstPartyBranding(object):

    """Implementation of the 'FirstPartyBranding' model.

    Specifies first party branding for a store or other entity.

    Attributes:
        brand (CookiesBrandEnum): Specifies a first-party brand owned or
            operated by Cookies.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "brand": 'brand'
    }

    def __init__(self,
                 brand=None):
        """Constructor for the FirstPartyBranding class"""

        # Initialize members of the class
        self.brand = brand

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        brand = dictionary.get('brand')

        # Return an object of this model
        return cls(brand)
