# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class StoreCapabilityEnum(object):

    """Implementation of the 'StoreCapability' enum.

    Enumerates available store capabilities.

    Attributes:
        PICKUP: Pickup ordering.
        DELIVERY: Delivery ordering.
        CURBSIDE: Curbside pickup ordering.
        LOYALTY: Globally-enrolled loyalty.
        DEBIT: Accepts debit cards.
        MEDICAL: Licensed for medical sales.
        ADULT_USE: Licensed for adult-use sales.

    """

    PICKUP = 'PICKUP'

    DELIVERY = 'DELIVERY'

    CURBSIDE = 'CURBSIDE'

    LOYALTY = 'LOYALTY'

    DEBIT = 'DEBIT'

    MEDICAL = 'MEDICAL'

    ADULT_USE = 'ADULT_USE'
