# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class StoreStatusEnum(object):

    """Implementation of the 'StoreStatus' enum.

    Specifies the current status of a store or D2C property.

    Attributes:
        OPEN: The store or property is open for business.
        CLOSED: The store or property is closed for business.
        PICKUP_ONLY: The store or property is open for pickup only.
        DELIVERY_ONLY: The store or property is open for delivery only.

    """

    OPEN = 'OPEN'

    CLOSED = 'CLOSED'

    PICKUP_ONLY = 'PICKUP_ONLY'

    DELIVERY_ONLY = 'DELIVERY_ONLY'
