# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from cookiesapi.models.first_party_branding import FirstPartyBranding


class StoreBranding(object):

    """Implementation of the 'StoreBranding' model.

    Branding information for a physical retail store.

    Attributes:
        first_party (FirstPartyBranding): Specifies the first-party brand for
            a store.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "first_party": 'firstParty'
    }

    def __init__(self,
                 first_party=None):
        """Constructor for the StoreBranding class"""

        # Initialize members of the class
        self.first_party = first_party

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        first_party = FirstPartyBranding.from_dictionary(dictionary.get('firstParty')) if dictionary.get('firstParty') else None

        # Return an object of this model
        return cls(first_party)
