# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class MediaType(object):

    """Implementation of the 'MediaType' model.

    Specifies type information for a media asset.

    Attributes:
        image_type (string): Specifies an image format, as applicable.
        kind (string): Specifies the broad "kind" of media.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "image_type": 'imageType',
        "kind": 'kind'
    }

    def __init__(self,
                 image_type=None,
                 kind=None):
        """Constructor for the MediaType class"""

        # Initialize members of the class
        self.image_type = image_type
        self.kind = kind

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        image_type = dictionary.get('imageType')
        kind = dictionary.get('kind')

        # Return an object of this model
        return cls(image_type,
                   kind)
