# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class SpeciesEnum(object):

    """Implementation of the 'Species' enum.

    OpenCannabis species specifier.

    Attributes:
        UNSPECIFIED: The item has no species, or the species value is not
            applicable.
        SATIVA: The item is assigned SATIVA species.
        HYBRID_SATIVA: The item is assigned HYBRID species that leans SATIVA.
        HYBRID: The item is assigned pure HYBRID species.
        HYBRID_INDICA: The item is assigned HYBRID species that leans INDICA.
        INDICA: The item is assigned INDICA species.

    """

    UNSPECIFIED = 'UNSPECIFIED'

    SATIVA = 'SATIVA'

    HYBRID_SATIVA = 'HYBRID_SATIVA'

    HYBRID = 'HYBRID'

    HYBRID_INDICA = 'HYBRID_INDICA'

    INDICA = 'INDICA'
