# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class MaterialInfo(object):

    """Implementation of the 'MaterialInfo' model.

    Describes material or operational regarding about a Cookies strain.

    Attributes:
        breeder (string): Breeder(s) who produced a strain.
        aroma (string): Aroma notes for a strain.
        flavor (string): Flavor notes for a strain.
        experience (string): Experience notes for a strain.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "breeder": 'breeder',
        "aroma": 'aroma',
        "flavor": 'flavor',
        "experience": 'experience'
    }

    def __init__(self,
                 breeder=None,
                 aroma=None,
                 flavor=None,
                 experience=None):
        """Constructor for the MaterialInfo class"""

        # Initialize members of the class
        self.breeder = breeder
        self.aroma = aroma
        self.flavor = flavor
        self.experience = experience

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        breeder = dictionary.get('breeder')
        aroma = dictionary.get('aroma')
        flavor = dictionary.get('flavor')
        experience = dictionary.get('experience')

        # Return an object of this model
        return cls(breeder,
                   aroma,
                   flavor,
                   experience)
