# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class StoreTypeEnum(object):

    """Implementation of the 'StoreType' enum.

    Enumerates types of Cookies stores.

    Attributes:
        FIRST_PARTY: Describes a first-party Cookies store.
        THIRD_PARTY: Describes a third-party store that carries Cookies
            products.
        NETWORK: Describes a store affiliated with Cookies.

    """

    FIRST_PARTY = 'FIRST_PARTY'

    THIRD_PARTY = 'THIRD_PARTY'

    NETWORK = 'NETWORK'
