# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class CookiesBrandEnum(object):

    """Implementation of the 'CookiesBrand' enum.

    Specifies 1st-party store brands.

    Attributes:
        COOKIES: Specifies the brand "Cookies".
        LEMONNADE: Specifies the brand "Lemonnade".

    """

    COOKIES = 'COOKIES'

    LEMONNADE = 'LEMONNADE'
